@@ -9,7 +9,7 @@ use Error::Pure::Utils qw(err_get);
 use MARC::Leader;
 use MARC::Field008;
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 sub name {
 	my $self = shift;
@@ -22,14 +22,35 @@ sub process {
 
 	my $struct_hr = $self->{'struct'}->{'checks'};
 
+	my $error_id = $self->{'cb_error_id'}->($marc_record);
+
 	my $leader_string = $marc_record->leader;
-	my $leader = MARC::Leader->new(
-		'verbose' => $self->{'verbose'},
-	)->parse($leader_string);
+	my $leader = eval {
+		MARC::Leader->new(
+			'verbose' => $self->{'verbose'},
+		)->parse($leader_string);
+	};
+	if ($EVAL_ERROR) {
+		my @errors = err_get(1);
+		$struct_hr->{'not_valid'}->{$error_id} = [];
+		foreach my $error (@errors) {
+			my %err_params = @{$error->{'msg'}}[1 .. $#{$error->{'msg'}}];
+			push @{$struct_hr->{'not_valid'}->{$error_id}}, {
+				'error' => $error->{'msg'}->[0],
+				'params' => \%err_params,
+			};
+		}
+		return;
+	}
 
-	my $cnb = $marc_record->field('015')->subfield('a');
-
-	my $field_008_string = $marc_record->field('008')->as_string;
+	my $field_008_obj = $marc_record->field('008');
+	if (! defined $field_008_obj) {
+		push @{$struct_hr->{'not_valid'}->{$error_id}}, {
+			'error' => 'Field 008 is not present.',
+		};
+		return;
+	}
+	my $field_008_string = $field_008_obj->as_string;
 	my $field_008 = eval {
 		MARC::Field008->new(
 			'leader' => $leader,
@@ -38,10 +59,10 @@ sub process {
 	};
 	if ($EVAL_ERROR) {
 		my @errors = err_get(1);
-		$struct_hr->{'not_valid'}->{$cnb} = [];
+		$struct_hr->{'not_valid'}->{$error_id} = [];
 		foreach my $error (@errors) {
 			my %err_params = @{$error->{'msg'}}[1 .. $#{$error->{'msg'}}];
-			push @{$struct_hr->{'not_valid'}->{$cnb}}, {
+			push @{$struct_hr->{'not_valid'}->{$error_id}}, {
 				'error' => $error->{'msg'}->[0],
 				'params' => \%err_params,
 			};
@@ -51,7 +72,7 @@ sub process {
 	} else {
 		if ($field_008->type_of_date eq 's') {
 			if ($field_008->date1 eq '    ') {
-				$struct_hr->{'not_valid'}->{$cnb} = [{
+				$struct_hr->{'not_valid'}->{$error_id} = [{
 					'error' => 'Field 008 date 1 need to be fill.',
 					'params' => {
 						'Value', $field_008_string,
@@ -59,7 +80,7 @@ sub process {
 				}];
 			} else {
 				if ($field_008->date1 eq $field_008->date2) {
-					$struct_hr->{'not_valid'}->{$cnb} = [{
+					$struct_hr->{'not_valid'}->{$error_id} = [{
 						'error' => 'Field 008 date 1 is same as date 2.',
 						'params' => {
 							'Value', $field_008_string,
